function ax_plot(x,y);
%function ax_plot(x,y);
%
% AX_PLOT -- Produces a scatter-plot with axis lines and the unit circle
%
% Input Parameters:
%    x   -- a vector of x-components of the scatter plot
%    y   -- a vector of y-components of the scatter plot
%
% Example:
%   ax_plot([.2 .4 .6],[.8 .1 .2]);

% Rearrange input arrays if necessary
if size(x,1) < size(x,2)
    x = x';
end
if size(y,1) < size(y,2)
    y = y';
end

cla
hold on

% Draw the unit circle
c = -pi:.01:pi;
plot(cos(c),sin(c),'k:')

% Plot the x and y axes
h = plot(x,y,'kx');
axis image
set(h,'MarkerSize',10);

% Set the axes so we can see all of the data points
axis([min([x-.2;-1]),max([x+.2;1]),min([y;-.2-1]),max([y+.2;1])]);

% Draw the x and y axis lines
ax = axis;
h = line(ax(1:2),[0 0]);
set(h,'color',[0 0 0]);
h = line([0 0],ax(3:4));
set(h,'color',[0 0 0]);

hold off